@@ -34,6 +34,14 @@ macro_rules! udata {
 				$fieldvis $field: $ty
 			),*
 		}
+
+		impl $name {
+			pub fn new( $($field: $ty),* ) -> $name {
+				$name {
+					$($field),*
+				}
+			}
+		}
 		udata!( $($rest)* );
 	};
 	() => ()
@@ -41,6 +49,7 @@ macro_rules! udata {
 
 udata! {
 	// https://github.com/danielga/sourcesdk-minimal/blob/cab3e07edc4a41e7e69ea645ea51c1e5c5d1be71/public/mathlib/vector.h#L66
+	/// Floating point vector type created by the Vector() function in lua and Vector::new() in Rust.
 	pub struct Vector {
 		pub x: f32,
 		pub y: f32,
@@ -48,7 +57,8 @@ udata! {
 	}
 
 	// https://github.com/danielga/sourcesdk-minimal/blob/cab3e07edc4a41e7e69ea645ea51c1e5c5d1be71/public/mathlib/vector.h#L1765
-	/// QAngle
+	/// Euler angle type.
+	/// This is a QAngle in the source engine.
 	pub struct Angle {
 		pub p: f32,
 		pub y: f32,
